@@ -1,4 +1,6 @@
 from pome.models.accounts_chart import *
 from pome.models.address import *
+from pome.models.bill import *
+from pome.models.invoice import *
 from pome.models.company import *
 from pome.models.settings import *
